Stoq Developer Howto
====================

Welcome to the Stoq Developer Howto.
This will help you get started with the Stoq development.

As soon as you're finished you should be able to contribute patches
on your own and have a basic understanding on the whole system.

Expect it to take around 10 hours to complete the whole tutorial
if you're not experienced in all different areas.

.. toctree::
   :maxdepth: 2

   Directory structure <structure>
   Learning an editor <editor>
   Introduction to the UNIX shell <unix>
   Python and the shell <python>
   Gtk and Kiwi <gtk>
   Stoq domain classes <domain>
   Creating a developer environment <devenv>
   The Stoq development process <process>

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

